@@ -45,19 +45,18 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtklabel.h>
 
-#include <nautilus-burn-drive-monitor.h>
-#include <nautilus-burn-drive.h>
-
 #include "brasero-utils.h"
 #include "brasero-disc.h"
 #include "brasero-tray.h"
 #include "brasero-burn-dialog.h"
+#include "brasero-jacket-edit.h"
+
 #include "burn-basics.h"
 #include "burn-session.h"
 #include "burn-medium.h"
 #include "brasero-drive-selection.h"
 #include "brasero-progress.h"
-#include "brasero-ncb.h"
+#include "burn-drive.h"
 
 static void brasero_burn_dialog_class_init (BraseroBurnDialogClass *klass);
 static void brasero_burn_dialog_init (BraseroBurnDialog *obj);
@@ -79,25 +78,18 @@ static void
 brasero_burn_dialog_tray_show_dialog_cb (BraseroTrayIcon *tray,
 					 gboolean show,
 					 GtkWidget *dialog);
-static void
-brasero_burn_dialog_tray_close_after_cb (BraseroTrayIcon *tray,
-					 gboolean close,
-					 BraseroBurnDialog *dialog);
 
 struct BraseroBurnDialogPrivate {
 	BraseroBurn *burn;
 	BraseroTrackType input;
 	BraseroBurnSession *session;
 
-	GtkWidget *close_check;
 	GtkWidget *progress;
 	GtkWidget *header;
 	GtkWidget *cancel;
 	GtkWidget *image;
 	BraseroTrayIcon *tray;
 
-	gint close_timeout;
-
 	guint is_writing:1;
 };
 
@@ -164,10 +156,10 @@ brasero_burn_dialog_update_info (BraseroBurnDialog *dialog,
 					      "iso-image-new",
 					      GTK_ICON_SIZE_DIALOG);
 
-		header = g_strdup_printf ("<big><b>Creating image</b></big>");
+		header = g_strdup (_("<big><b>Creating image</b></big>"));
 		title = g_strdup (_("Brasero - Creating image"));
 	}
-	else if (media & BRASERO_MEDIUM_DVD) {
+	else if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL)) {
 		if (input == BRASERO_TRACK_TYPE_DATA) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY) {
 				title = g_strdup (_("Brasero - Burning DVD (simulation)"));
@@ -215,11 +207,11 @@ brasero_burn_dialog_update_info (BraseroBurnDialog *dialog,
 		if (input == BRASERO_TRACK_TYPE_AUDIO) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY) {
 				title = g_strdup (_("Brasero - Burning CD (simulation)"));
-				header = g_strdup_printf (_("<big><b>Simulation of audio CD burning</b></big>"));
+				header = g_strdup (_("<big><b>Simulation of audio CD burning</b></big>"));
 			}
 			else {
 				title = g_strdup (_("Brasero - Burning CD"));
-				header = g_strdup_printf (_("<big><b>Burning audio CD</b></big>"));
+				header = g_strdup (_("<big><b>Burning audio CD</b></big>"));
 			}
 
 			gtk_image_set_from_icon_name (GTK_IMAGE (dialog->priv->image),
@@ -229,11 +221,11 @@ brasero_burn_dialog_update_info (BraseroBurnDialog *dialog,
 		else if (input == BRASERO_TRACK_TYPE_DATA) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY) {
 				title = g_strdup (_("Brasero - Burning CD (simulation)"));
-				header = g_strdup_printf (_("<big><b>Simulation of data CD burning</b></big>"));
+				header = g_strdup (_("<big><b>Simulation of data CD burning</b></big>"));
 			}
 			else {
 				title = g_strdup (_("Brasero - Burning CD"));
-				header = g_strdup_printf (_("<big><b>Burning data CD</b></big>"));
+				header = g_strdup (_("<big><b>Burning data CD</b></big>"));
 			}
 
 			gtk_image_set_from_icon_name (GTK_IMAGE (dialog->priv->image),
@@ -272,11 +264,11 @@ brasero_burn_dialog_update_info (BraseroBurnDialog *dialog,
 	else if (input == BRASERO_TRACK_TYPE_AUDIO) {
 		if (flags & BRASERO_BURN_FLAG_DUMMY) {
 			title = g_strdup (_("Brasero - Burning CD (simulation)"));
-			header = g_strdup_printf (_("<big><b>Simulation of audio CD burning</b></big>"));
+			header = g_strdup (_("<big><b>Simulation of audio CD burning</b></big>"));
 		}
 		else {
 			title = g_strdup (_("Brasero - Burning CD"));
-			header = g_strdup_printf (_("<big><b>Burning audio CD</b></big>"));
+			header = g_strdup (_("<big><b>Burning audio CD</b></big>"));
 		}
 
 		gtk_image_set_from_icon_name (GTK_IMAGE (dialog->priv->image),
@@ -286,11 +278,11 @@ brasero_burn_dialog_update_info (BraseroBurnDialog *dialog,
 	else if (input == BRASERO_TRACK_TYPE_DATA) {
 		if (flags & BRASERO_BURN_FLAG_DUMMY) {
 			title = g_strdup (_("Brasero - Burning disc (simulation)"));
-			header = g_strdup_printf (_("<big><b>Simulation of data disc burning</b></big>"));
+			header = g_strdup (_("<big><b>Simulation of data disc burning</b></big>"));
 		}
 		else {
 			title = g_strdup (_("Brasero - Burning disc"));
-			header = g_strdup_printf (_("<big><b>Burning data disc</b></big>"));
+			header = g_strdup (_("<big><b>Burning data disc</b></big>"));
 		}
 
 		gtk_image_set_from_icon_name (GTK_IMAGE (dialog->priv->image),
@@ -369,36 +361,36 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 				     NULL,
 				     NULL);
 
-		if ((type & BRASERO_MEDIUM_CD) && !(type & BRASERO_MEDIUM_DVD)) {
+		if ((type & BRASERO_MEDIUM_CD) && !(type & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))) {
 			if (!insert) {
 				if (isosize)
 					message = g_strdup_printf (_("replace the disc with a recordable CD with a least %i MiB free."), 
 								   (int) (isosize / 1048576));
 				else
-					message = g_strdup_printf (_("replace the disc with a recordable CD."));
+					message = g_strdup (_("replace the disc with a recordable CD."));
 			}
 			else {
 				if (isosize)
 					message = g_strdup_printf (_("insert a recordable CD with a least %i MiB free."), 
 								   (int) (isosize / 1048576));
 				else
-					message = g_strdup_printf (_("insert a recordable CD."));
+					message = g_strdup (_("insert a recordable CD."));
 			}
 		}
-		else if (!(type & BRASERO_MEDIUM_CD) && (type & BRASERO_MEDIUM_DVD)) {
+		else if (!(type & BRASERO_MEDIUM_CD) && (type & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))) {
 			if (!insert) {
 				if (isosize)
 					message = g_strdup_printf (_("replace the disc with a recordable DVD with a least %i MiB free."), 
 								   (int) (isosize / 1048576));
 				else
-					message = g_strdup_printf (_("replace the disc with a recordable DVD."));
+					message = g_strdup (_("replace the disc with a recordable DVD."));
 			}
 			else {
 				if (isosize)
 					message = g_strdup_printf (_("insert a recordable DVD with a least %i MiB free."), 
 								   (int) (isosize / 1048576));
 				else
-					message = g_strdup_printf (_("insert a recordable DVD."));
+					message = g_strdup (_("insert a recordable DVD."));
 			}
 		}
 		else if (!insert) {
@@ -406,14 +398,14 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 				message = g_strdup_printf (_("replace the disc with a recordable CD or DVD with a least %i MiB free."), 
 							   (int) (isosize / 1048576));
 			else
-				message = g_strdup_printf (_("replace the disc with a recordable CD or DVD."));
+				message = g_strdup (_("replace the disc with a recordable CD or DVD."));
 		}
 		else {
 			if (isosize)
 				message = g_strdup_printf (_("insert a recordable CD or DVD with a least %i MiB free."), 
 							   (int) (isosize / 1048576));
 			else
-				message = g_strdup_printf (_("insert a recordable CD or DVD."));
+				message = g_strdup (_("insert a recordable CD or DVD."));
 		}
 	}
 
@@ -421,7 +413,8 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 }
 
 static void
-brasero_burn_dialog_wait_for_insertion (NautilusBurnDrive *drive,
+brasero_burn_dialog_wait_for_insertion (BraseroDrive *drive,
+					BraseroMedium *medium,
 					GtkDialog *message)
 {
 	/* we might have a dialog waiting for the 
@@ -431,7 +424,7 @@ brasero_burn_dialog_wait_for_insertion (NautilusBurnDrive *drive,
 
 static BraseroBurnResult
 brasero_burn_dialog_insert_disc_cb (BraseroBurn *burn,
-				    NautilusBurnDrive *drive,
+				    BraseroDrive *drive,
 				    BraseroBurnError error,
 				    BraseroMedia type,
 				    BraseroBurnDialog *dialog)
@@ -441,6 +434,7 @@ brasero_burn_dialog_insert_disc_cb (BraseroBurn *burn,
 	gchar *drive_name;
 	GtkWindow *window;
 	GtkWidget *message;
+	BraseroMedium *medium;
 	gboolean hide = FALSE;
 	gchar *main_message = NULL, *secondary_message = NULL;
 
@@ -450,14 +444,17 @@ brasero_burn_dialog_insert_disc_cb (BraseroBurn *burn,
 	}
 
 	if (drive)
-		drive_name = nautilus_burn_drive_get_name_for_display (drive);
+		drive_name = brasero_drive_get_display_name (drive);
 	else
 		drive_name = NULL;
 
-	if (error == BRASERO_BURN_WARNING_CHECKSUM) {
+	if (error == BRASERO_BURN_WARNING_INSERT_AFTER_COPY) {
+		main_message = g_strdup (_("An image of the disc has been created on your hard drive. Burning is about to begin:"));
+		secondary_message = brasero_burn_dialog_get_media_type_string (burn, type, FALSE);
+	}
+	else if (error == BRASERO_BURN_WARNING_CHECKSUM) {
 		main_message = g_strdup (_("A data integrity test is about to begin:"));
-		secondary_message = g_strdup_printf (_("please, insert the disc to check in \"%s\"."),
-						     drive_name);
+		secondary_message = g_strdup (_("Please, re-insert the disc in the CD/DVD burner."));
 	}
 	else if (error == BRASERO_BURN_WARNING_NEXT_COPY) {
 		main_message = g_strdup (_("A recording was successfully completed."
@@ -556,7 +553,7 @@ brasero_burn_dialog_insert_disc_cb (BraseroBurn *burn,
 
 	/* connect to signals to be warned when media is inserted */
 	added_id = g_signal_connect_after (drive,
-					   "media-added",
+					   "medium-added",
 					   G_CALLBACK (brasero_burn_dialog_wait_for_insertion),
 					   message);
 
@@ -566,20 +563,22 @@ brasero_burn_dialog_insert_disc_cb (BraseroBurn *burn,
 	gtk_widget_destroy (message);
 
 	/* see if we should update the infos */
+	medium = brasero_burn_session_get_src_medium (dialog->priv->session);
 	if (dialog->priv->input.type == BRASERO_TRACK_TYPE_DISC) {
-		NautilusBurnDrive *src;
+		BraseroMedium *medium;
+		BraseroDrive *src;
 
 		/* see if the drive is the source */
 		src = brasero_burn_session_get_src_drive (dialog->priv->session);
-		if (nautilus_burn_drive_equal (src, drive))
+		if (drive == src)
 			brasero_burn_dialog_update_info (dialog,
 							 dialog->priv->input.type, 
-							 NCB_MEDIA_GET_STATUS (drive));
+							 brasero_medium_get_status (medium));
 	}
 	else
 		brasero_burn_dialog_update_info (dialog,
 						 dialog->priv->input.type, 
-						 NCB_MEDIA_GET_STATUS (drive));
+						 brasero_medium_get_status (medium));
 
 	if (hide)
 		gtk_widget_hide (GTK_WIDGET (dialog));
@@ -663,8 +662,8 @@ brasero_burn_dialog_data_loss_cb (BraseroBurn *burn,
 {
 	return brasero_burn_dialog_loss_warnings_cb (dialog,
 						     _("Possible loss of data"),
-						     _("The disc in the drive holds data:"),
-						     _("Do you want to erase the current disc?\nOr replace the current disc with a new disc?"),
+						     _("Do you really want to erase the current disc?"),
+						     _("The disc in the drive holds data."),
 						     _("Erase disc"),
 						     "media-optical-blank");
 }
@@ -726,10 +725,10 @@ brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
 					  GTK_DIALOG_MODAL,
 					  GTK_MESSAGE_WARNING,
 					  GTK_BUTTONS_NONE,
-					  _("Some files don't have a suitable name for a Windows-compatible CD:"));
+					  _("Do you want to continue with Windows compatibility disabled?"));
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
-						  _("Do you want to continue with Windows compatibility disabled?"));
+						  _("Some files don't have a suitable name for a Windows-compatible CD:"));
 
 	gtk_window_set_title (GTK_WINDOW (message), _("Windows compatibility"));
 	gtk_dialog_add_buttons (GTK_DIALOG (message),
@@ -775,19 +774,19 @@ brasero_burn_dialog_update_title_writing_progress (BraseroBurnDialog *dialog,
 	else if (media & BRASERO_MEDIUM_DVD) {
 		if (input == BRASERO_TRACK_TYPE_DATA) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Burning DVD (simulation)"));
+				title = g_strdup (_("Brasero - Burning DVD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Burning DVD (%i%% done)"), percent);
 		}
 		else if (input == BRASERO_TRACK_TYPE_IMAGE) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Burning DVD (simulation)"));
+				title = g_strdup (_("Brasero - Burning DVD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Burning DVD (%i%% done)"), percent);
 		}
 		else if (input == BRASERO_TRACK_TYPE_DISC) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Copying DVD (simulation)"));
+				title = g_strdup (_("Brasero - Copying DVD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Copying DVD (%i%% done)"), percent);
 		}
@@ -795,50 +794,50 @@ brasero_burn_dialog_update_title_writing_progress (BraseroBurnDialog *dialog,
 	else if (media & BRASERO_MEDIUM_CD) {
 		if (input == BRASERO_TRACK_TYPE_AUDIO) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Burning CD (simulation)"));
+				title = g_strdup (_("Brasero - Burning CD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Burning CD (%i%% done)"), percent);
 		}
 		else if (input == BRASERO_TRACK_TYPE_DATA) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Burning CD (simulation)"));
+				title = g_strdup (_("Brasero - Burning CD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Burning CD (%i%% done)"), percent);
 		}
 		else if (input == BRASERO_TRACK_TYPE_DISC) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Copying CD (simulation)"));
+				title = g_strdup (_("Brasero - Copying CD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Copying CD (%i%% done)"), percent);
 		}
 		else if (input == BRASERO_TRACK_TYPE_IMAGE) {
 			if (flags & BRASERO_BURN_FLAG_DUMMY)
-				title = g_strdup_printf (_("Brasero - Burning CD (simulation)"));
+				title = g_strdup (_("Brasero - Burning CD (simulation)"));
 			else
 				title = g_strdup_printf (_("Brasero - Burning CD (%i%% done)"), percent);
 		}
 	}
 	else if (input == BRASERO_TRACK_TYPE_AUDIO) {
 		if (flags & BRASERO_BURN_FLAG_DUMMY)
-			title = g_strdup_printf (_("Brasero - Burning CD (simulation)"));
+			title = g_strdup (_("Brasero - Burning CD (simulation)"));
 		else
 			title = g_strdup_printf (_("Brasero - Burning CD (%i%% done)"), percent);
 	}
 	else if (input == BRASERO_TRACK_TYPE_DATA) {
 		if (flags & BRASERO_BURN_FLAG_DUMMY)
-			title = g_strdup_printf (_("Brasero - Burning disc (simulation)"));
+			title = g_strdup (_("Brasero - Burning disc (simulation)"));
 		else
 			title = g_strdup_printf (_("Brasero - Burning disc (%i%% done)"), percent);
 	}
 	else if (input == BRASERO_TRACK_TYPE_DISC) {
 		if (flags & BRASERO_BURN_FLAG_DUMMY)
-			title = g_strdup_printf (_("Brasero - Copying disc (simulation)"));
+			title = g_strdup (_("Brasero - Copying disc (simulation)"));
 		else
 			title = g_strdup_printf (_("Brasero - Copying disc (%i%% done)"), percent);
 	}
 	else if (input == BRASERO_TRACK_TYPE_IMAGE) {
 		if (flags & BRASERO_BURN_FLAG_DUMMY)
-			title = g_strdup_printf (_("Brasero - Burning disc (simulation)"));
+			title = g_strdup (_("Brasero - Burning disc (simulation)"));
 		else
 			title = g_strdup_printf (_("Brasero - Burning disc (%i%% done)"), percent);
 	}
@@ -889,7 +888,7 @@ brasero_burn_dialog_progress_changed_real (BraseroBurnDialog *dialog,
 								   (guint) (task_progress * 100.0));
 
 	brasero_burn_progress_set_status (BRASERO_BURN_PROGRESS (dialog->priv->progress),
-					  (media & BRASERO_MEDIUM_DVD),
+					  (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL)),
 					  overall_progress,
 					  task_progress,
 					  remaining,
@@ -1008,7 +1007,7 @@ brasero_burn_dialog_dummy_success_cb (BraseroBurn *burn,
 	button = brasero_utils_make_button (_("Burn Now"),
 					    NULL,
 					    "media-optical-burn",
-					    GTK_ICON_SIZE_LARGE_TOOLBAR);
+					    GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (button);
 	gtk_dialog_add_action_widget (GTK_DIALOG (message), button, GTK_RESPONSE_OK);
 
@@ -1057,12 +1056,9 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 			  "show-dialog",
 			  G_CALLBACK (brasero_burn_dialog_tray_show_dialog_cb),
 			  obj);
-	g_signal_connect (obj->priv->tray,
-			  "close-after",
-			  G_CALLBACK (brasero_burn_dialog_tray_close_after_cb),
-			  obj);
 
 	alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
+	gtk_widget_show (alignment);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 8, 6, 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (obj)->vbox),
 			    alignment,
@@ -1071,35 +1067,34 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 			    0);
 
 	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_widget_show (vbox);
 	gtk_container_add (GTK_CONTAINER (alignment), vbox);
 
 	box = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (box);
 	gtk_box_pack_start (GTK_BOX (vbox), box, TRUE, TRUE, 0);
 
 	obj->priv->header = gtk_label_new (NULL);
+	gtk_widget_show (obj->priv->header);
 	gtk_misc_set_alignment (GTK_MISC (obj->priv->header), 0.0, 0.5);
 	gtk_misc_set_padding (GTK_MISC (obj->priv->header), 0, 18);
 	gtk_box_pack_start (GTK_BOX (box), obj->priv->header, TRUE, TRUE, 0);
 
 	obj->priv->image = gtk_image_new ();
+	gtk_widget_show (obj->priv->image);
 	gtk_box_pack_start (GTK_BOX (box), obj->priv->image, FALSE, FALSE, 0);
 
 	obj->priv->progress = brasero_burn_progress_new ();
+	gtk_widget_show (obj->priv->progress);
 	gtk_box_pack_start (GTK_BOX (vbox),
 			    obj->priv->progress,
 			    FALSE,
 			    FALSE,
 			    0);
 
-	obj->priv->close_check = gtk_check_button_new_with_mnemonic (_("_Close the application if the burn process is successful"));
-	gtk_box_pack_end (GTK_BOX (obj->priv->progress),
-			  obj->priv->close_check,
-			  FALSE,
-			  FALSE,
-			  0);
-
 	/* buttons */
 	obj->priv->cancel = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+	gtk_widget_show (obj->priv->cancel);
 	gtk_dialog_add_action_widget (GTK_DIALOG (obj),
 				      obj->priv->cancel,
 				      GTK_RESPONSE_CANCEL);
@@ -1139,11 +1134,6 @@ brasero_burn_dialog_finalize (GObject * object)
 		cobj->priv->tray = NULL;
 	}
 
-	if (cobj->priv->close_timeout) {
-		g_source_remove (cobj->priv->close_timeout);
-		cobj->priv->close_timeout = 0;
-	}
-
 	if (cobj->priv->session) {
 		g_object_unref (cobj->priv->session);
 		cobj->priv->session = NULL;
@@ -1561,33 +1551,25 @@ brasero_burn_dialog_notify_error (BraseroBurnDialog *dialog,
 	gtk_widget_destroy (message);
 }
 
-static gboolean
-brasero_burn_dialog_success_timeout (BraseroBurnDialog *dialog)
-{
-	gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	dialog->priv->close_timeout = 0;
-
-	return FALSE;
-}
-
 static void
 brasero_burn_dialog_success_run (BraseroBurnDialog *dialog)
 {
 	gint answer;
 
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->close_check))) {
-		dialog->priv->close_timeout = g_timeout_add (TIMEOUT,
-							     (GSourceFunc) brasero_burn_dialog_success_timeout,
-							     dialog);
-
-	}
-
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
+	if (answer == GTK_RESPONSE_CLOSE) {
+		GtkWidget *contents;
+		GtkWidget *window;
+		const gchar *title;
+		GSList *tracks;
 
-	/* remove the timeout if need be */
-	if (dialog->priv->close_timeout) {
-		g_source_remove (dialog->priv->close_timeout);
-		dialog->priv->close_timeout = 0;
+		contents = brasero_jacket_edit_dialog_new (GTK_WIDGET (dialog), &window);
+
+		title = brasero_burn_session_get_label (dialog->priv->session);
+		tracks = brasero_burn_session_get_tracks (dialog->priv->session);
+		brasero_jacket_edit_set_audio_tracks (BRASERO_JACKET_EDIT (contents), title, tracks);
+
+		gtk_dialog_run (GTK_DIALOG (window));
 	}
 }
 
@@ -1595,9 +1577,8 @@ static void
 brasero_burn_dialog_notify_success (BraseroBurnDialog *dialog)
 {
 	BraseroMedia media;
+	BraseroDrive *drive;
 	gchar *primary = NULL;
-	gchar *secondary = NULL;
-	NautilusBurnDrive *drive;
 
 	drive = brasero_burn_session_get_burner (dialog->priv->session);
 	if (dialog->priv->input.type != BRASERO_TRACK_TYPE_DISC)
@@ -1608,69 +1589,58 @@ brasero_burn_dialog_notify_success (BraseroBurnDialog *dialog)
 	switch (dialog->priv->input.type) {
 	case BRASERO_TRACK_TYPE_AUDIO:
 		primary = g_strdup (_("Audio CD successfully burnt"));
-		secondary = g_strdup_printf (_("\"%s\" is now ready for use"), 
-					     brasero_burn_session_get_label (dialog->priv->session));
 		break;
 	case BRASERO_TRACK_TYPE_DISC:
-		if (NCB_DRIVE_GET_TYPE (drive) != NAUTILUS_BURN_DRIVE_TYPE_FILE) {
-			if (media & BRASERO_MEDIUM_DVD) {
+		if (!brasero_drive_is_fake (drive)) {
+			if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))
 				primary = g_strdup (_("DVD successfully copied"));
-				secondary = g_strdup_printf (_("DVD is now ready for use"));
-			}
-			else {
+			else
 				primary = g_strdup (_("CD successfully copied"));
-				secondary = g_strdup_printf (_("CD is now ready for use"));
-			}
 		}
 		else {
-			if (media & BRASERO_MEDIUM_DVD) {
+			if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))
 				primary = g_strdup (_("Image of DVD successfully created"));
-				secondary = g_strdup_printf (_("DVD is now ready for use"));
-			}
-			else {
+			else
 				primary = g_strdup (_("Image of CD successfully created"));
-				secondary = g_strdup_printf (_("CD is now ready for use"));
-			}
 		}
 		break;
 	case BRASERO_TRACK_TYPE_IMAGE:
-		if (NCB_DRIVE_GET_TYPE (drive) != NAUTILUS_BURN_DRIVE_TYPE_FILE) {
-			if (media & BRASERO_MEDIUM_DVD) {
+		if (!brasero_drive_is_fake (drive)) {
+			if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))
 				primary = g_strdup (_("Image successfully burnt to DVD"));
-				secondary = g_strdup_printf (_("DVD is now ready for use"));
-			}
-			else {
+			else
 				primary = g_strdup (_("Image successfully burnt to CD"));
-				secondary = g_strdup_printf (_("CD is now ready for use"));
-			}
 		}
 		break;
 	default:
-		if (NCB_DRIVE_GET_TYPE (drive) != NAUTILUS_BURN_DRIVE_TYPE_FILE) {
-			if (media & BRASERO_MEDIUM_DVD) {
+		if (!brasero_drive_is_fake (drive)) {
+			if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))
 				primary = g_strdup (_("Data DVD successfully burnt"));
-				secondary = g_strdup_printf (_("\"%s\" is now ready for use"),
-							     brasero_burn_session_get_label (dialog->priv->session));
-			}
-			else {
+			else
 				primary = g_strdup (_("Data CD successfully burnt"));
-				secondary = g_strdup_printf (_("\"%s\" is now ready for use"),
-							     brasero_burn_session_get_label (dialog->priv->session));
-			}
 		}
-		else {
+		else
 			primary = g_strdup (_("Image successfully created"));
-			secondary = g_strdup_printf (_("\"%s\" is now ready for use"),
-						     brasero_burn_session_get_label (dialog->priv->session));
-		}
 		break;
 	}
 
 	brasero_burn_dialog_activity_stop (dialog, primary);
+
+	if (brasero_burn_session_get_input_type (dialog->priv->session, NULL) == BRASERO_TRACK_TYPE_AUDIO) {
+		GtkWidget *button;
+
+		/* since we succeed offer the possibility to create cover if that's an audio disc */
+		button = brasero_utils_make_button (_("Create cover"),
+						    NULL,
+						    NULL,
+						    GTK_ICON_SIZE_BUTTON);
+		gtk_widget_show (button);
+		gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_CLOSE);
+	}
+
 	brasero_burn_dialog_success_run (dialog);
 
 	g_free (primary);
-	g_free (secondary);
 }
 
 static void
@@ -1740,8 +1710,6 @@ brasero_burn_dialog_end_session (BraseroBurnDialog *dialog,
 				 BraseroBurnResult result,
 				 GError *error)
 {
-	gboolean close_dialog;
-
 	if (dialog->priv->burn) {
 		g_object_unref (dialog->priv->burn);
 		dialog->priv->burn = NULL;
@@ -1751,10 +1719,8 @@ brasero_burn_dialog_end_session (BraseroBurnDialog *dialog,
 
 	if (result == BRASERO_BURN_CANCEL) {
 		/* nothing to do */
-		close_dialog = FALSE;
 	}
 	else if (error || result != BRASERO_BURN_OK) {
-		close_dialog = FALSE;
 		brasero_burn_dialog_notify_error (dialog, error);
 	}
 	else {
@@ -1772,15 +1738,15 @@ brasero_burn_dialog_end_session (BraseroBurnDialog *dialog,
 		}
 
 		brasero_burn_dialog_notify_success (dialog);
-		close_dialog = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->close_check));
 	}
 
-	return close_dialog;
+	return FALSE;
 }
 
 gboolean
 brasero_burn_dialog_run (BraseroBurnDialog *dialog,
-			 BraseroBurnSession *session)
+			 BraseroBurnSession *session,
+			 gboolean *destroy)
 {
 	BraseroMedia media;
 	GError *error = NULL;
@@ -1797,10 +1763,10 @@ brasero_burn_dialog_run (BraseroBurnDialog *dialog,
 	else if (dialog->priv->input.type != BRASERO_TRACK_TYPE_DISC)
 		media = brasero_burn_session_get_dest_media (session);
 	else {
-		NautilusBurnDrive *drive;
+		BraseroMedium *medium;
 
-		drive = brasero_burn_session_get_src_drive (dialog->priv->session);
-		media = NCB_MEDIA_GET_STATUS (drive);
+		medium = brasero_burn_session_get_src_medium (dialog->priv->session);
+		media = brasero_medium_get_status (medium);
 	}
 
 	brasero_burn_dialog_update_info (dialog, dialog->priv->input.type, media);
@@ -1809,17 +1775,10 @@ brasero_burn_dialog_run (BraseroBurnDialog *dialog,
 	brasero_burn_dialog_activity_start (dialog);
 
 	result = brasero_burn_dialog_setup_session (dialog, &error);
-	if (result == BRASERO_BURN_OK) {
-		NautilusBurnDrive *drive;
-		BraseroBurnFlag flags;
-
-		drive = brasero_burn_session_get_burner (session);
-		flags = brasero_burn_session_get_flags (session);
-
+	if (result == BRASERO_BURN_OK)
 		result = brasero_burn_record (dialog->priv->burn,
 					      session,
 					      &error);
-	}
 
 	close_dialog = brasero_burn_dialog_end_session (dialog,
 							result,
@@ -1828,7 +1787,10 @@ brasero_burn_dialog_run (BraseroBurnDialog *dialog,
 	g_object_unref (dialog->priv->session);
 	dialog->priv->session = NULL;
 
-	return close_dialog;
+	if (destroy)
+		*destroy = close_dialog;
+
+	return (result == BRASERO_BURN_OK);
 }
 
 static gboolean
@@ -1851,11 +1813,7 @@ brasero_burn_dialog_cancel_dialog (GtkWidget *toplevel)
 						  (message),
 						  _("Interrupting the process may make disc unusable."));
 
-	gtk_dialog_add_buttons (GTK_DIALOG (message),
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				NULL);
-
-	button = brasero_utils_make_button (_("Continue"),
+	button = brasero_utils_make_button (("C_ontinue burning"),
 					    GTK_STOCK_OK,
 					    NULL,
 					    GTK_ICON_SIZE_BUTTON);
@@ -1863,6 +1821,14 @@ brasero_burn_dialog_cancel_dialog (GtkWidget *toplevel)
 	gtk_dialog_add_action_widget (GTK_DIALOG (message),
 				      button, GTK_RESPONSE_OK);
 
+	button = brasero_utils_make_button (_("_Cancel burning"),
+					    GTK_STOCK_CANCEL,
+					    NULL,
+					    GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show_all (button);
+	gtk_dialog_add_action_widget (GTK_DIALOG (message),
+				      button, GTK_RESPONSE_CANCEL);
+
 	result = gtk_dialog_run (GTK_DIALOG (message));
 	gtk_widget_destroy (message);
 
@@ -1936,11 +1902,3 @@ brasero_burn_dialog_tray_show_dialog_cb (BraseroTrayIcon *tray,
 	else
 		gtk_widget_hide (dialog);
 }
-
-static void
-brasero_burn_dialog_tray_close_after_cb (BraseroTrayIcon *tray,
-					 gboolean close,
-					 BraseroBurnDialog *dialog)
-{
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->close_check), close);
-}
