@@ -42,8 +42,6 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkmessagedialog.h>
 
-#include <nautilus-burn-drive.h>
-
 #include <gconf/gconf-client.h>
 
 #include "burn-basics.h"
@@ -52,7 +50,7 @@
 #include "burn-medium.h"
 #include "burn-session.h"
 #include "burn-plugin-manager.h"
-#include "brasero-ncb.h"
+#include "burn-drive.h"
 #include "brasero-drive-selection.h"
 #include "brasero-drive-properties.h"
 #include "brasero-image-properties.h"
@@ -97,6 +95,8 @@ enum {
 };
 static guint brasero_dest_selection_signals [LAST_SIGNAL] = { 0 };
 
+#define BRASERO_DEST_SAVED_FLAGS	(BRASERO_DRIVE_PROPERTIES_FLAGS|BRASERO_BURN_FLAG_MULTI)
+
 static void
 brasero_dest_selection_save_drive_properties (BraseroDestSelection *self)
 {
@@ -105,7 +105,6 @@ brasero_dest_selection_save_drive_properties (BraseroDestSelection *self)
 	GConfClient *client;
 	const gchar *path;
 	guint64 rate;
-	guint speed;
 	gchar *key;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
@@ -113,19 +112,24 @@ brasero_dest_selection_save_drive_properties (BraseroDestSelection *self)
 	client = gconf_client_get_default ();
 
 	rate = brasero_burn_session_get_rate (priv->session);
-	if (brasero_burn_session_get_dest_media (priv->session) & BRASERO_MEDIUM_DVD)
-		speed = BRASERO_RATE_TO_SPEED_DVD (rate);
-	else
-		speed = BRASERO_RATE_TO_SPEED_CD (rate);
-
 	key = brasero_burn_session_get_config_key (priv->session, "speed");
-	gconf_client_set_int (client, key, speed, NULL);
+	if (!key) {
+		g_object_unref (client);
+		return;
+	}
+
+	gconf_client_set_int (client, key, rate / 1024, NULL);
 	g_free (key);
 
 	key = brasero_burn_session_get_config_key (priv->session, "flags");
+	if (!key) {
+		g_object_unref (client);
+		return;
+	}
+
 	flags = gconf_client_get_int (client, key, NULL);
 	flags &= ~BRASERO_DRIVE_PROPERTIES_FLAGS;
-	flags |= (brasero_burn_session_get_flags (priv->session) & BRASERO_DRIVE_PROPERTIES_FLAGS);
+	flags |= (brasero_burn_session_get_flags (priv->session) & BRASERO_DEST_SAVED_FLAGS);
 	gconf_client_set_int (client, key, flags, NULL);
 	g_free (key);
 
@@ -142,7 +146,8 @@ static gboolean
 brasero_dest_selection_check_same_src_dest (BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
-	NautilusBurnDrive *drive;
+	BraseroMedium *medium;
+	BraseroDrive *drive;
 	BraseroMedia media;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
@@ -160,8 +165,8 @@ brasero_dest_selection_check_same_src_dest (BraseroDestSelection *self)
 	if (!drive)
 		return FALSE;
 
-	media = NCB_MEDIA_GET_STATUS (drive);
-	g_object_unref (drive);
+	medium = brasero_drive_get_medium (drive);
+	media = brasero_medium_get_status (medium);;
 
 	if (media == BRASERO_MEDIUM_NONE)
 		return FALSE;
@@ -180,7 +185,7 @@ brasero_dest_selection_drive_properties (BraseroDestSelection *self)
 	BraseroBurnFlag compulsory = 0;
 	BraseroBurnFlag supported = 0;
 	BraseroBurnFlag flags = 0;
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
 	GtkWidget *toplevel;
 	const gchar *path;
 	gint result;
@@ -203,7 +208,6 @@ brasero_dest_selection_drive_properties (BraseroDestSelection *self)
 	brasero_drive_properties_set_drive (BRASERO_DRIVE_PROPERTIES (priv->drive_prop),
 					    drive,
 					    rate);
-	nautilus_burn_drive_unref (drive);
 
 	flags = brasero_burn_session_get_flags (priv->session);
 	if (!brasero_dest_selection_check_same_src_dest (self)) {
@@ -231,7 +235,6 @@ brasero_dest_selection_drive_properties (BraseroDestSelection *self)
 	gtk_widget_show_all (priv->drive_prop);
 	result = gtk_dialog_run (GTK_DIALOG (priv->drive_prop));
 	if (result != GTK_RESPONSE_ACCEPT) {
-		nautilus_burn_drive_unref (drive);
 		gtk_widget_destroy (priv->drive_prop);
 		priv->drive_prop = NULL;
 		return;
@@ -327,7 +330,7 @@ brasero_dest_selection_get_default_output_format (BraseroDestSelection *self,
 		return;
 
 	if (source.type == BRASERO_TRACK_TYPE_DATA
-	||  source.subtype.media & BRASERO_MEDIUM_DVD) {
+	||  source.subtype.media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL)) {
 		output->subtype.img_format = BRASERO_IMAGE_FORMAT_BIN;
 		result = brasero_burn_caps_is_output_supported (priv->caps,
 								priv->session,
@@ -565,7 +568,7 @@ brasero_dest_selection_image_extension_ask (BraseroDestSelection *self)
 					 GTK_DIALOG_DESTROY_WITH_PARENT |
 					 GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_YES_NO,
+					 GTK_BUTTONS_NONE,
 					 _("Do you really want to keep the current extension for the disc image name?"));
 
 		
@@ -573,6 +576,13 @@ brasero_dest_selection_image_extension_ask (BraseroDestSelection *self)
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  _("If you choose to keep it programs may not be able to recognize the file type properly."));
 
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Don't change extension"),
+			       GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("Change _extension"),
+			       GTK_RESPONSE_YES);
+
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
@@ -684,7 +694,7 @@ brasero_dest_selection_properties_button_cb (GtkWidget *button,
 					     BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
 
@@ -692,7 +702,7 @@ brasero_dest_selection_properties_button_cb (GtkWidget *button,
 	if (!drive)
 		return;
 
-	if (NCB_DRIVE_GET_TYPE (drive) == NAUTILUS_BURN_DRIVE_TYPE_FILE)
+	if (brasero_drive_is_fake (drive))
 		brasero_dest_selection_image_properties (self);
 	else
 		brasero_dest_selection_drive_properties (self);
@@ -797,9 +807,10 @@ static void
 brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
-	NautilusBurnDrive *drive;
 	BraseroTrackType source;
 	BraseroBurnFlag flags;
+	BraseroMedium *medium;
+	BraseroDrive *drive;
 	GConfClient *client;
 	GConfValue *value;
 	gchar *path;
@@ -818,6 +829,19 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 		return;
 	}
 
+	if (brasero_burn_session_is_dest_file (priv->session)) {
+		BraseroBurnResult result;
+
+		result = brasero_burn_caps_is_session_supported (priv->caps, priv->session);
+		g_signal_emit (self,
+			       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
+			       0,
+			       (result == BRASERO_BURN_OK));
+
+		gtk_widget_set_sensitive (priv->button, (result == BRASERO_BURN_OK));
+		return;
+	}
+
 	drive = brasero_burn_session_get_burner (priv->session);
 	if (!drive) {
 		g_signal_emit (self,
@@ -825,15 +849,18 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 			       0,
 			       FALSE);
 		gtk_widget_set_sensitive (priv->button, FALSE);
+		gtk_widget_set_sensitive (priv->copies_box, FALSE);
 		return;
 	}
 
-	if (NCB_MEDIA_GET_STATUS (drive) == BRASERO_MEDIUM_NONE) {
+	medium = brasero_drive_get_medium (drive);
+	if (!medium || brasero_medium_get_status (medium) == BRASERO_MEDIUM_NONE) {
 		g_signal_emit (self,
 			       brasero_dest_selection_signals [VALID_MEDIA_SIGNAL],
 			       0,
 			       FALSE);
 		gtk_widget_set_sensitive (priv->button, FALSE);
+		gtk_widget_set_sensitive (priv->copies_box, FALSE);
 		return;
 	}
 
@@ -841,17 +868,18 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 	client = gconf_client_get_default ();
 
 	key = brasero_burn_session_get_config_key (priv->session, "speed");
+	if (!key) {
+		g_object_unref (client);
+		return;
+	}
+
 	value = gconf_client_get_without_default (client, key, NULL);
 	g_free (key);
 
 	if (!value)
-		rate = NCB_MEDIA_GET_MAX_WRITE_RATE (drive);
-	else if (NCB_MEDIA_GET_STATUS (drive) & BRASERO_MEDIUM_DVD) {
-		rate = BRASERO_SPEED_TO_RATE_DVD (gconf_value_get_int (value));
-		gconf_value_free (value);
-	}
+		rate = brasero_medium_get_max_write_speed (medium);
 	else {
-		rate = BRASERO_SPEED_TO_RATE_CD (gconf_value_get_int (value));
+		rate = gconf_value_get_int (value) * 1024;
 		gconf_value_free (value);
 	}
 
@@ -862,6 +890,11 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 	 * Indeed two flags could be mutually exclusive and then adding both at
 	 * the same would make the session unusable (MULTI and BLANK_BEFORE_WRITE) */
 	key = brasero_burn_session_get_config_key (priv->session, "flags");
+	if (!key) {
+		g_object_unref (client);
+		return;
+	}
+
 	value = gconf_client_get_without_default (client, key, NULL);
 	g_free (key);
 
@@ -904,7 +937,8 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 						  BRASERO_BURN_FLAG_DAO);
 
 		/* set new ones */
-		flags = gconf_value_get_int (value);
+		flags = gconf_value_get_int (value) & BRASERO_DEST_SAVED_FLAGS;
+		gconf_value_free (value);
 		brasero_burn_session_add_flag (priv->session, flags);
 
 		/* NOTE: of course NO_TMP is not possible; DAO and BLANK_BEFORE
@@ -930,8 +964,9 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 		BraseroBurnFlag compulsory = BRASERO_BURN_FLAG_NONE;
 
 		/* set the saved flags (make sure they are supported) */
-		flags = gconf_value_get_int (value);
+		flags = gconf_value_get_int (value) & BRASERO_DEST_SAVED_FLAGS;
 		gconf_value_free (value);
+
 		brasero_dest_selection_add_drive_properties_flags (self,
 								   flags,
 								   &supported,
@@ -949,8 +984,6 @@ brasero_dest_selection_set_drive_properties (BraseroDestSelection *self)
 		gtk_widget_set_sensitive (priv->button, (result == BRASERO_BURN_OK));
 	}
 
-	nautilus_burn_drive_unref (drive);
-
 	key = g_strdup_printf ("%s/tmpdir", BRASERO_DRIVE_PROPERTIES_KEY);
 	path = gconf_client_get_string (client, key, NULL);
 	brasero_burn_session_set_tmpdir (priv->session, path);
@@ -1097,7 +1130,7 @@ brasero_dest_selection_check_image_settings (BraseroDestSelection *self)
 
 static void
 brasero_dest_selection_check_drive_settings (BraseroDestSelection *self,
-					     NautilusBurnDrive *drive)
+					     BraseroDrive *drive)
 {
 	BraseroBurnFlag compulsory = BRASERO_BURN_FLAG_NONE;
 	BraseroBurnFlag supported = BRASERO_BURN_FLAG_NONE;
@@ -1164,6 +1197,19 @@ static void
 brasero_dest_selection_source_changed (BraseroBurnSession *session,
 				       BraseroDestSelection *self)
 {
+	BraseroDestSelectionPrivate *priv;
+
+	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
+
+	if (brasero_burn_session_is_dest_file (priv->session)) {
+		/* check that if a path was set there may be none if there was
+		 * no disc inserted when the dialog was created. */
+		if (brasero_burn_session_get_output (priv->session, NULL, NULL, NULL) != BRASERO_BURN_OK)
+			brasero_dest_selection_set_image_properties (self);
+
+		return;
+	}
+
 	/* NOTE: that can't happen if we are going to write to an image since
 	 * that would mean we are changing the image format (something we don't
 	 * do. So it has to be when we write to a drive */
@@ -1174,7 +1220,7 @@ static void
 brasero_dest_selection_caps_changed (BraseroPluginManager *manager,
 				     BraseroDestSelection *self)
 {
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
 	BraseroDestSelectionPrivate *priv;
 
 	/* In this case we are still in the same context (same src, dest) so we
@@ -1189,12 +1235,10 @@ brasero_dest_selection_caps_changed (BraseroPluginManager *manager,
 	if (!drive)
 		return;
 
-	if (NCB_DRIVE_GET_TYPE (drive) != NAUTILUS_BURN_DRIVE_TYPE_FILE)
+	if (!brasero_drive_is_fake (drive))
 		brasero_dest_selection_check_drive_settings (self, drive);
 	else
 		brasero_dest_selection_check_image_settings (self);
-
-	nautilus_burn_drive_unref (drive);
 }
 
 static void
@@ -1202,8 +1246,8 @@ brasero_dest_selection_output_changed (BraseroBurnSession *session,
 				       BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
-	NautilusBurnDrive *burner;
-	NautilusBurnDrive *drive;
+	BraseroDrive *burner;
+	BraseroDrive *drive;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
 
@@ -1216,14 +1260,18 @@ brasero_dest_selection_output_changed (BraseroBurnSession *session,
 
 	/* make sure the current displayed drive reflects that */
 	drive = brasero_drive_selection_get_drive (BRASERO_DRIVE_SELECTION (self));
-	if (drive && burner && !nautilus_burn_drive_equal (burner, drive)) {
+	if (drive && burner && burner != drive)
 		brasero_drive_selection_set_drive (BRASERO_DRIVE_SELECTION (self), drive);
-	}
 
 	if (drive)
-		nautilus_burn_drive_unref (drive);
+		g_object_unref (drive);
 
-	if (NCB_DRIVE_GET_TYPE (burner) != NAUTILUS_BURN_DRIVE_TYPE_FILE) {
+	if (!burner) {
+		brasero_dest_selection_set_drive_properties (self);
+		return;
+	}
+
+	if (!brasero_drive_is_fake (burner)) {
 		gint numcopies;
 
 		brasero_dest_selection_set_drive_properties (self);
@@ -1248,7 +1296,7 @@ brasero_dest_selection_output_changed (BraseroBurnSession *session,
 
 static void
 brasero_dest_selection_drive_changed (BraseroDriveSelection *selection,
-				      NautilusBurnDrive *drive)
+				      BraseroDrive *drive)
 {
 	BraseroDestSelectionPrivate *priv;
 
@@ -1292,6 +1340,7 @@ brasero_dest_selection_init (BraseroDestSelection *object)
 					   object);
 
 	priv->button = gtk_button_new_from_stock (GTK_STOCK_PROPERTIES);
+	gtk_widget_show (priv->button);
 	gtk_widget_set_tooltip_text (priv->button, _("Configure some options for the recording"));
 	g_signal_connect (G_OBJECT (priv->button),
 			  "clicked",
@@ -1299,7 +1348,7 @@ brasero_dest_selection_init (BraseroDestSelection *object)
 			  object);
 
 	brasero_drive_selection_set_tooltip (BRASERO_DRIVE_SELECTION (object),
-					     _("Choose which drive holds the disc to write to"));
+					     _("Choose the disc to write to"));
 
 	brasero_drive_selection_set_button (BRASERO_DRIVE_SELECTION (object),
 					    priv->button);
@@ -1321,7 +1370,11 @@ brasero_dest_selection_init (BraseroDestSelection *object)
 			  G_CALLBACK (brasero_dest_selection_copies_num_changed_cb),
 			  object);
 
-	brasero_drive_selection_set_show_all_drives (BRASERO_DRIVE_SELECTION (object), FALSE);
+	/* Only show media on which we can write and which are in a burner.
+	 * There is one exception though, when we're copying media and when the
+	 * burning device is the same as the dest device. */
+	brasero_drive_selection_set_type_shown (BRASERO_DRIVE_SELECTION (object),
+						BRASERO_MEDIA_TYPE_WRITABLE);
 
 	priv->default_ext = TRUE;
 	priv->default_path = TRUE;
@@ -1374,7 +1427,7 @@ brasero_dest_selection_set_property (GObject *object,
 {
 	BraseroDestSelectionPrivate *priv;
 	BraseroBurnSession *session;
-	NautilusBurnDrive *drive;
+	BraseroDrive *drive;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (object);
 
@@ -1392,9 +1445,13 @@ brasero_dest_selection_set_property (GObject *object,
 
 		drive = brasero_drive_selection_get_drive (BRASERO_DRIVE_SELECTION (object));
 		brasero_burn_session_set_burner (session, drive);
-		nautilus_burn_drive_unref (drive);
 
-		if (brasero_burn_session_is_dest_file (session))
+		if (drive)
+			g_object_unref (drive);
+
+		if (brasero_burn_session_same_src_dest_drive (priv->session))
+			brasero_drive_selection_set_same_src_dest (BRASERO_DRIVE_SELECTION (object));
+		else if (brasero_burn_session_is_dest_file (session))
 			brasero_dest_selection_set_image_properties (BRASERO_DEST_SELECTION (object));
 		else
 			brasero_dest_selection_set_drive_properties (BRASERO_DEST_SELECTION (object));
