@@ -39,8 +39,14 @@ G_BEGIN_DECLS
 					 BRASERO_BURN_FLAG_OVERBURN|		\
 					 BRASERO_BURN_FLAG_NOGRACE|		\
 					 BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|	\
-					 BRASERO_BURN_FLAG_APPEND)
+					 BRASERO_BURN_FLAG_APPEND|		\
+					 BRASERO_BURN_FLAG_MERGE)
 
+#define BRASERO_PLUGIN_IMAGE_FLAG_MASK	(BRASERO_BURN_FLAG_APPEND|		\
+					 BRASERO_BURN_FLAG_MERGE)
+
+#define BRASERO_PLUGIN_BLANK_FLAG_MASK	(BRASERO_BURN_FLAG_NOGRACE|		\
+					 BRASERO_BURN_FLAG_FAST_BLANK)
 
 #define BRASERO_TYPE_PLUGIN             (brasero_plugin_get_type ())
 #define BRASERO_PLUGIN(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), BRASERO_TYPE_PLUGIN, BraseroPlugin))
@@ -123,6 +129,12 @@ void
 brasero_plugin_blank_caps (BraseroPlugin *plugin,
 			   GSList *caps);
 
+/**
+ * This function is important since not only does it set the flags but it also 
+ * tells brasero which types of media are supported. So even if a plugin doesn't
+ * support any flag, use it to tell brasero which media are supported.
+ * That's only needed if the plugin supports burn/blank operations.
+ */
 void
 brasero_plugin_set_flags (BraseroPlugin *plugin,
 			  BraseroMedia media,
@@ -158,6 +170,7 @@ typedef enum {
 	BRASERO_PLUGIN_OPTION_BOOL,
 	BRASERO_PLUGIN_OPTION_INT,
 	BRASERO_PLUGIN_OPTION_STRING,
+	BRASERO_PLUGIN_OPTION_CHOICE
 } BraseroPluginConfOptionType;
 
 BraseroPluginConfOption *
@@ -178,6 +191,11 @@ brasero_plugin_conf_option_int_set_range (BraseroPluginConfOption *option,
 					  gint min,
 					  gint max);
 
+BraseroBurnResult
+brasero_plugin_conf_option_choice_add (BraseroPluginConfOption *option,
+				       const gchar *string,
+				       gint value);
+
 /**
  * Boiler plate for plugin definition to save the hassle of definition.
  * To be put at the beginning of the .c file.
