@@ -26,6 +26,8 @@
 #  include <config.h>
 #endif
 
+#include <math.h>
+
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n-lib.h>
@@ -199,6 +201,8 @@ brasero_task_ctx_get_session (BraseroTaskCtx *self)
 {
 	BraseroTaskCtxPrivate *priv;
 
+	g_return_val_if_fail (BRASERO_IS_TASK_CTX (self), NULL);
+
 	priv = BRASERO_TASK_CTX_PRIVATE (self);
 	if (!priv->session)
 		return NULL;
@@ -801,13 +805,21 @@ brasero_task_ctx_get_progress (BraseroTaskCtx *self,
 	gdouble track_num = 0;
 	gdouble track_nb = 0;
 	gint64 total = -1;
-	GSList *tracks;
 
 	priv = BRASERO_TASK_CTX_PRIVATE (self);
 
-	tracks = brasero_burn_session_get_tracks (priv->session);
-	track_num = g_slist_length (tracks);
-	track_nb = g_slist_index (tracks, priv->current_track);
+	/* The following can happen when we're blanking since there's no track */
+	if (priv->action == BRASERO_TASK_ACTION_ERASE) {
+		track_num = 1.0;
+		track_nb = 0.0;
+	}
+	else {
+		GSList *tracks;
+
+		tracks = brasero_burn_session_get_tracks (priv->session);
+		track_num = g_slist_length (tracks);
+		track_nb = g_slist_index (tracks, priv->current_track);
+	}
 
 	if (priv->progress >= 0.0) {
 		if (progress)
