@@ -31,37 +31,38 @@
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
+
+#include <gio/gio.h>
+
 #include <gtk/gtk.h>
 
 #include <gst/gst.h>
+#include <gst/pbutils/pbutils.h>
 
+#include <libgnome/gnome-help.h>
 #include <libgnomeui/libgnomeui.h>
 
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-
-#include <nautilus-burn-recorder.h>
-#include <nautilus-burn-init.h>
-
 #include <gconf/gconf-client.h>
 
-#ifdef HAVE_LIBNOTIFY
-#include <libnotify/notify.h>
-#endif
-
 #include "brasero-app.h"
 #include "brasero-menu.h"
+#include "brasero-jacket-edit.h"
 #include "brasero-multi-dnd.h"
 #include "brasero-blank-dialog.h"
 #include "brasero-sum-dialog.h"
+#include "brasero-eject-dialog.h"
 #include "brasero-session.h"
 #include "brasero-project-manager.h"
-#include "brasero-ncb.h"
+#include "burn-drive.h"
 #include "brasero-pref.h"
 #include "burn-debug.h"
+#include "burn.h"
+#include "burn-caps.h"
+#include "burn-plugin-manager.h"
 
 static GConfClient *client;
 gchar *project_uri;
+gchar *playlist_uri;
 gchar *iso_uri;
 gchar **files;
 gchar **audio_project;
@@ -78,6 +79,14 @@ static const GOptionEntry options [] = {
 	  N_("Open the specified project"),
 	  N_("PROJECT") },
 
+#ifdef BUILD_PLAYLIST
+
+	 { "playlist", 'l', G_OPTION_FLAG_FILENAME, G_OPTION_ARG_STRING, &playlist_uri,
+	  N_("Open the specified playlist as an audio project"),
+	  N_("PLAYLIST") },
+
+#endif
+
 	{ "audio", 'a', 0, G_OPTION_ARG_NONE, &audio_project,
 	  N_("Open an audio project adding the URIs given on the command line"),
 	  NULL },
@@ -118,8 +127,11 @@ static const GOptionEntry options [] = {
 
 #define BRASERO_PROJECT_OPEN_URI(app, function, path)	\
 {									\
+	GFile *file;							\
 	gchar *uri;							\
-	uri = gnome_vfs_make_uri_from_input (path);			\
+	file = g_file_new_for_commandline_arg (path);			\
+	uri = g_file_get_uri (file);					\
+	g_object_unref (file);						\
 	function (BRASERO_PROJECT_MANAGER (app->contents), uri);	\
 }
 
@@ -130,7 +142,10 @@ static const GOptionEntry options [] = {
 	/* convert all names into a GSList * */	\
 	for (iter = uris; iter && *iter; iter ++) {				\
 		gchar *uri;							\
-		uri = gnome_vfs_make_uri_from_input (*iter);			\
+		GFile *file;							\
+		file = g_file_new_for_commandline_arg (*iter);			\
+		uri = g_file_get_uri (file);					\
+		g_object_unref (file);						\
 		list = g_slist_prepend (list, uri);				\
 	}									\
 	function (BRASERO_PROJECT_MANAGER (app->contents), list);		\
@@ -173,7 +188,23 @@ on_erase_cb (GtkAction *action, BraseroApp *app)
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-	gtk_widget_show_all (dialog);
+	gtk_widget_show (dialog);
+}
+
+void
+on_eject_cb (GtkAction *action, BraseroApp *app)
+{
+	GtkWidget *dialog;
+	GtkWidget *toplevel;
+
+	dialog = brasero_eject_dialog_new();
+	toplevel = gtk_widget_get_toplevel (app->mainwin);
+
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
+
+	gtk_widget_show (dialog);
 }
 
 void
@@ -189,7 +220,7 @@ on_integrity_check_cb (GtkAction *action, BraseroApp *app)
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-	gtk_widget_show_all (dialog);
+	gtk_widget_show (dialog);
 }
 
 void
@@ -225,7 +256,9 @@ on_about_cb (GtkAction *action, BraseroApp *app)
 	};
 
 	const gchar *documenters[] = {
-		N_("Sorry, no documentation for Brasero."),
+		"Phil Bull <philbull@gmail.com>"
+		"Milo Casagrande <milo_casagrande@yahoo.it>"
+		"Andrew Stabeno <stabeno@gmail.com>",
 		NULL
 	};
 
@@ -284,6 +317,28 @@ on_about_cb (GtkAction *action, BraseroApp *app)
 	g_free (license);
 }
 
+void
+on_help_cb (GtkAction *action, BraseroApp *app)
+{
+    	GError *error = NULL;
+    
+ 	gnome_help_display ("brasero.xml",
+			     NULL,
+			     &error);
+   	if (error) {
+		GtkWidget *d;
+        
+		d = gtk_message_dialog_new (GTK_WINDOW (app->mainwin),
+					    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+					    error->message);
+		gtk_dialog_run (GTK_DIALOG(d));
+		gtk_widget_destroy (d);
+		g_error_free (error);
+		error = NULL;
+	}
+}
+
 static gboolean
 on_window_state_changed_cb (GtkWidget *widget,
 			    GdkEventWindowState *event,
@@ -344,22 +399,7 @@ brasero_app_recent_open (GtkRecentChooser *chooser,
 		return;
 	}
 
-	if (!strcmp (mime, "application/x-brasero")) {
-		BRASERO_PROJECT_OPEN_URI (app,
-					  brasero_project_manager_open,
-					  gtk_recent_info_get_uri (item));
-	}
-    	else if (!strcmp (mime, "application/x-cd-image")
-	     ||  !strcmp (mime, "application/x-cdrdao-toc")
-	     ||  !strcmp (mime, "application/x-toc")
-	     ||  !strcmp (mime, "application/x-cue")) {
-    		BRASERO_PROJECT_OPEN_URI (app,
-					  brasero_project_manager_iso,
-					  gtk_recent_info_get_uri (item));
-	}
-	else
-		g_warning ("Unknown type of file can't open");
-
+	brasero_project_manager_open_by_mime (BRASERO_PROJECT_MANAGER (app->contents), uri, mime);
 	gtk_recent_info_unref (item);
 }
 
@@ -385,12 +425,17 @@ brasero_app_add_recent (BraseroApp *app,
 	gtk_recent_filter_add_mime_type (filter, "application/x-cdrdao-toc");
 	gtk_recent_filter_add_mime_type (filter, "application/x-toc");
 	gtk_recent_filter_add_mime_type (filter, "application/x-cue");
+	gtk_recent_filter_add_mime_type (filter, "audio/x-scpls");
+	gtk_recent_filter_add_mime_type (filter, "audio/x-ms-asx");
+	gtk_recent_filter_add_mime_type (filter, "audio/x-mp3-playlist");
+	gtk_recent_filter_add_mime_type (filter, "audio/x-mpegurl");
+
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (action), filter);
 	gtk_recent_chooser_set_filter (GTK_RECENT_CHOOSER (action), filter);
 
 	gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (action), TRUE);
 
-	gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (action), 20);
+	gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (action), 5);
 
 	gtk_recent_chooser_set_show_tips (GTK_RECENT_CHOOSER (action), TRUE);
 
@@ -469,14 +514,34 @@ brasero_disconnect_ui_manager_proxy_cb (GtkUIManager *manager,
 					      app);
 }
 
+static void
+brasero_caps_changed_cb (BraseroPluginManager *manager,
+			 BraseroApp *app)
+{
+	BraseroBurnCaps *caps;
+	GtkWidget *widget;
+
+	caps = brasero_burn_caps_get_default ();
+	widget = gtk_ui_manager_get_widget (app->manager, "/menubar/ToolMenu/Check");
+
+	if (!brasero_burn_caps_can_checksum (caps))
+		gtk_widget_set_sensitive (widget, FALSE);
+	else
+		gtk_widget_set_sensitive (widget, TRUE);
+
+	g_object_unref (caps);
+}
+
 static BraseroApp *
 brasero_app_create_app (void)
 {
 	BraseroApp *app;
 	GtkWidget *menubar;
 	GError *error = NULL;
+	BraseroBurnCaps *caps;
 	GtkAccelGroup *accel_group;
 	GtkActionGroup *action_group;
+	BraseroPluginManager *plugin_manager;
 
 	/* New window */
 	app = g_new0 (BraseroApp, 1);
@@ -537,6 +602,22 @@ brasero_app_create_app (void)
 	menubar = gtk_ui_manager_get_widget (app->manager, "/menubar");
 	gnome_app_set_menus (GNOME_APP (app->mainwin), GTK_MENU_BAR (menubar));
 
+	/* check if we can use checksums (we need plugins enabled) */
+	caps = brasero_burn_caps_get_default ();
+	if (!brasero_burn_caps_can_checksum (caps)) {
+		GtkWidget *widget;
+
+		widget = gtk_ui_manager_get_widget (app->manager, "/menubar/ToolMenu/Check");
+		gtk_widget_set_sensitive (widget, FALSE);
+	}
+	g_object_unref (caps);
+
+	plugin_manager = brasero_plugin_manager_get_default ();
+	g_signal_connect (plugin_manager,
+			  "caps-changed",
+			  G_CALLBACK (brasero_caps_changed_cb),
+			  app);
+
 	/* add accelerators */
 	accel_group = gtk_ui_manager_get_accel_group (app->manager);
 	gtk_window_add_accel_group (GTK_WINDOW (app->mainwin), accel_group);
@@ -577,6 +658,8 @@ brasero_app_parse_options (BraseroApp *app)
 		nb ++;
 	if (project_uri)
 		nb ++;
+	if (playlist_uri)
+		nb ++;
 	if (audio_project)
 		nb ++;
 	if (data_project)
@@ -613,8 +696,17 @@ brasero_app_parse_options (BraseroApp *app)
 		BRASERO_PROJECT_OPEN_URI (app, brasero_project_manager_iso, iso_uri);
 	}
 	else if (project_uri) {
-		BRASERO_PROJECT_OPEN_URI (app, brasero_project_manager_open, project_uri);
+		BRASERO_PROJECT_OPEN_URI (app, brasero_project_manager_open_project, project_uri);
 	}
+
+#ifdef BUILD_PLAYLIST
+
+	else if (playlist_uri) {
+		BRASERO_PROJECT_OPEN_URI (app, brasero_project_manager_open_playlist, playlist_uri);
+	}
+
+#endif
+
 	else if (audio_project) {
 		BRASERO_PROJECT_OPEN_LIST (app, brasero_project_manager_audio, files);
 	}
@@ -632,43 +724,27 @@ brasero_app_parse_options (BraseroApp *app)
 
 		/* in this case we can also add the files */
 		for (iter = files; iter && *iter; iter ++) {
+			GFile *file;
 			gchar *uri;
-			uri = gnome_vfs_make_uri_from_input (*iter);
-			list = g_slist_prepend (list, uri);
+
+			file = g_file_new_for_commandline_arg (*iter);
+			uri = g_file_get_uri (file);
+			g_object_unref (file);
+
+			list = g_slist_prepend (list, file);
 		}
 
 		brasero_project_manager_data (BRASERO_PROJECT_MANAGER (app->contents), list);
 		g_slist_free (list);
 	}
 	else if (files) {
-		const gchar *mime;
-	    	gchar *uri;
+		BraseroProjectType type;
 
 	    	if (g_strv_length (files) > 1)
 			BRASERO_PROJECT_OPEN_LIST (app, brasero_project_manager_data, files);
 
-		/* we need to determine what type of file it is */
-	    	uri = gnome_vfs_make_uri_from_input (files [0]);
-		mime = gnome_vfs_get_mime_type (uri);
-	    	g_free (uri);
-
-		if (mime) {
-			if (!strcmp (mime, "application/x-brasero")) {
-				BRASERO_PROJECT_OPEN_URI (app, brasero_project_manager_open, files [0]);
-			}
-			else if (!strcmp (mime, "application/x-cue")
-			     ||  !strcmp (mime, "application/x-toc")
-			     ||  !strcmp (mime, "application/x-cdrdao-toc")
-			     ||  !strcmp (mime, "application/x-cd-image")
-			     ||  !strcmp (mime, "application/octet-stream")) {
-				BRASERO_PROJECT_OPEN_URI (app, brasero_project_manager_iso, files [0]);
-			}
-			else {
-				/* open it in a data project */
-				BRASERO_PROJECT_OPEN_LIST (app, brasero_project_manager_data, files);
-			}
-		}
-		else
+		type = brasero_project_manager_open_uri (BRASERO_PROJECT_MANAGER (app->contents), files [0]);
+		if (type == BRASERO_PROJECT_TYPE_INVALID)
 			BRASERO_PROJECT_OPEN_LIST (app, brasero_project_manager_data, files);
 	}
 	else {
@@ -694,6 +770,7 @@ main (int argc, char **argv)
 	program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
 				      argc, argv,
 				      GNOME_PARAM_GOPTION_CONTEXT, context,
+				      GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
 				      GNOME_PARAM_HUMAN_READABLE_NAME, _("CD/DVD burning"),
 				      NULL);
 
@@ -706,13 +783,11 @@ main (int argc, char **argv)
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 
-#ifdef HAVE_LIBNOTIFY
-	notify_init (PACKAGE);
-#endif
-
-	gnome_vfs_init ();
 	gst_init (&argc, &argv);
 
+	/* This is for missing codec automatic install */
+	gst_pb_utils_init ();
+
 	brasero_burn_set_debug (debug);
 	brasero_burn_library_init ();
 
@@ -731,7 +806,6 @@ main (int argc, char **argv)
 
 	gtk_widget_show (app->mainwin);
 
-	/* debug */
 	gtk_main ();
 
 	brasero_burn_library_shutdown ();
@@ -740,8 +814,6 @@ main (int argc, char **argv)
 	g_free (app);
 	gst_deinit ();
 
-	nautilus_burn_shutdown ();
-
 	g_object_unref (client);
 	client = NULL;
 
