@@ -38,8 +38,6 @@
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include <nautilus-burn-drive.h>
-
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "burn-job.h"
@@ -241,7 +239,9 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 		g_ptr_array_add (argv, g_strdup ("-dvd-video"));
 
 	g_ptr_array_add (argv, g_strdup ("-graft-points"));
-	g_ptr_array_add (argv, g_strdup ("-D"));	// This is dangerous the manual says but apparently it works well
+
+	if (type.subtype.fs_type & BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY)
+		g_ptr_array_add (argv, g_strdup ("-D"));	// This is dangerous the manual says but apparently it works well
 
 	result = brasero_job_get_tmp_file (BRASERO_JOB (mkisofs),
 					   NULL,
@@ -287,19 +287,6 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 	g_ptr_array_add (argv, g_strdup ("-exclude-list"));
 	g_ptr_array_add (argv, excluded_path);
 
-	brasero_job_get_action (BRASERO_JOB (mkisofs), &action);
-	if (action == BRASERO_JOB_ACTION_SIZE) {
-		g_ptr_array_add (argv, g_strdup ("-quiet"));
-		g_ptr_array_add (argv, g_strdup ("-print-size"));
-
-		brasero_job_set_current_action (BRASERO_JOB (mkisofs),
-						BRASERO_BURN_ACTION_GETTING_SIZE,
-						NULL,
-						FALSE);
-		brasero_job_start_progress (BRASERO_JOB (mkisofs), FALSE);
-		return BRASERO_BURN_OK;
-	}
-
 	brasero_job_get_data_label (BRASERO_JOB (mkisofs), &label);
 	if (label) {
 		g_ptr_array_add (argv, g_strdup ("-V"));
@@ -348,11 +335,30 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 
 			g_ptr_array_add (argv, g_strdup ("-M"));
 
+#ifdef HAVE_CAM_LIB_H
+	/* FreeBSD like that better */
+			brasero_job_get_bus_target_lun (BRASERO_JOB (mkisofs), &device);
+#else
 			brasero_job_get_device (BRASERO_JOB (mkisofs), &device);
+#endif
+
 			g_ptr_array_add (argv, device);
 		}
 	}
 
+	brasero_job_get_action (BRASERO_JOB (mkisofs), &action);
+	if (action == BRASERO_JOB_ACTION_SIZE) {
+		g_ptr_array_add (argv, g_strdup ("-quiet"));
+		g_ptr_array_add (argv, g_strdup ("-print-size"));
+
+		brasero_job_set_current_action (BRASERO_JOB (mkisofs),
+						BRASERO_BURN_ACTION_GETTING_SIZE,
+						NULL,
+						FALSE);
+		brasero_job_start_progress (BRASERO_JOB (mkisofs), FALSE);
+		return BRASERO_BURN_OK;
+	}
+
 	if (brasero_job_get_fd_out (BRASERO_JOB (mkisofs), NULL) != BRASERO_BURN_OK) {
 		gchar *output = NULL;
 
@@ -485,6 +491,8 @@ brasero_mkisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 				  BRASERO_MEDIUM_DVDR|
 				  BRASERO_MEDIUM_DVDRW|
 				  BRASERO_MEDIUM_DVDR_PLUS|
+				  BRASERO_MEDIUM_RESTRICTED|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_HAS_AUDIO|
 				  BRASERO_MEDIUM_HAS_DATA,
