@@ -41,7 +41,7 @@
 #include "burn-plugin.h"
 #include "burn-job.h"
 #include "burn-process.h"
-#include "brasero-ncb.h"
+#include "burn-drive.h"
 #include "burn-growisofs.h"
 #include "burn-growisofs-common.h"
 
@@ -261,7 +261,9 @@ brasero_growisofs_set_mkisofs_argv (BraseroGrowisofs *growisofs,
 	}
 
 	g_ptr_array_add (argv, g_strdup ("-graft-points"));
-	g_ptr_array_add (argv, g_strdup ("-D"));	// This is dangerous the manual says but apparently it works well
+
+	if (input.subtype.fs_type & BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY)
+		g_ptr_array_add (argv, g_strdup ("-D"));	// This is dangerous the manual says but apparently it works well
 
 	result = brasero_job_get_tmp_file (BRASERO_JOB (growisofs),
 					   NULL,
@@ -658,7 +660,9 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_IMAGE_FORMAT_BIN);
 
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DVD_DL|
 					BRASERO_MEDIUM_PLUS|
+					BRASERO_MEDIUM_JUMP|
 					BRASERO_MEDIUM_SEQUENTIAL|
 					BRASERO_MEDIUM_WRITABLE|
 					BRASERO_MEDIUM_BLANK);
@@ -676,6 +680,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* and images to DVD RW +/-(restricted) whatever the status */
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DVD_DL|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_REWRITABLE|
@@ -689,9 +694,11 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* for DATA type recording discs can be also appendable */
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DVD_DL|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_SEQUENTIAL|
+					BRASERO_MEDIUM_JUMP|
 					BRASERO_MEDIUM_WRITABLE|
 					BRASERO_MEDIUM_REWRITABLE|
 					BRASERO_MEDIUM_BLANK|
@@ -710,6 +717,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* growisofs has the possibility to record to closed DVD+RW/-restricted
 	 * and to append some more data to them which makes it unique */
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DVD_DL|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_REWRITABLE|
@@ -723,7 +731,9 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	 * NOTE: DAO et MULTI are exclusive. */
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVD|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_SEQUENTIAL|
+				  BRASERO_MEDIUM_JUMP|
 				  BRASERO_MEDIUM_WRITABLE|
 				  BRASERO_MEDIUM_REWRITABLE|
 				  BRASERO_MEDIUM_BLANK,
@@ -736,7 +746,9 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVD|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_SEQUENTIAL|
+				  BRASERO_MEDIUM_JUMP|
 				  BRASERO_MEDIUM_WRITABLE|
 				  BRASERO_MEDIUM_REWRITABLE|
 				  BRASERO_MEDIUM_BLANK,
@@ -749,7 +761,9 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVD|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_SEQUENTIAL|
+				  BRASERO_MEDIUM_JUMP|
 				  BRASERO_MEDIUM_WRITABLE|
 				  BRASERO_MEDIUM_REWRITABLE|
 				  BRASERO_MEDIUM_APPENDABLE|
@@ -811,6 +825,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* DVD+ R/RW don't support dummy mode */
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDR_PLUS|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_BLANK,
 				  BRASERO_BURN_FLAG_DAO|
 				  BRASERO_BURN_FLAG_BURNPROOF|
@@ -820,6 +835,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDR_PLUS|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_BLANK,
 				  BRASERO_BURN_FLAG_BURNPROOF|
 				  BRASERO_BURN_FLAG_OVERBURN|
@@ -829,6 +845,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDR_PLUS|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_HAS_DATA,
 				  BRASERO_BURN_FLAG_BURNPROOF|
@@ -847,6 +864,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* for DVD+RW */
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDRW_PLUS|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_BLANK,
 				  BRASERO_BURN_FLAG_MULTI|
 				  BRASERO_BURN_FLAG_DAO|
@@ -857,6 +875,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDRW_PLUS|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_CLOSED|
 				  BRASERO_MEDIUM_HAS_DATA,
@@ -869,6 +888,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_DVDRW_PLUS|
+				  BRASERO_MEDIUM_DVD_DL|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_CLOSED|
 				  BRASERO_MEDIUM_HAS_DATA,
@@ -881,6 +901,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* blank caps for +/restricted RW*/
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DVD_DL|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_REWRITABLE|
@@ -906,6 +927,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* again DVD+RW don't support dummy */
 	brasero_plugin_set_blank_flags (plugin,
 					BRASERO_MEDIUM_DVDRW_PLUS|
+					BRASERO_MEDIUM_DVD_DL|
 					BRASERO_MEDIUM_APPENDABLE|
 					BRASERO_MEDIUM_HAS_DATA|
 					BRASERO_MEDIUM_BLANK|
